@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2019 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,6 +17,7 @@
 
 #include "logactivitieswidgettest.h"
 #include "../logactivitieswidget.h"
+#include "kdepimtest_layout.h"
 #include <KPIMTextEdit/PlainTextEditorWidget>
 #include <QTest>
 #include <QVBoxLayout>
@@ -35,7 +36,7 @@ void LogActivitiesWidgetTest::shouldHaveDefaultValue()
     PimCommon::LogActivitiesWidget w;
     QVBoxLayout *mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
     QVERIFY(mainLayout);
-    QCOMPARE(mainLayout->margin(), 0);
+    KdepimTestLayout::checkContentsMargins(0, mainLayout);
 
     KPIMTextEdit::PlainTextEditorWidget *mLog = w.findChild<KPIMTextEdit::PlainTextEditorWidget *>(QStringLiteral("log"));
     QVERIFY(mLog);
